@@ -281,7 +281,7 @@ sub insert {
 
 		if ($additional) { #addional queries run on insert
 			foreach my $field (keys %$additional) {
-				my $result = $self->db->getarray(@{$additional->{$field}->{sql}});
+				my $result = $self->db->getarray($additional->{$field}->{sql});
 
 				if (defined $result->[1] || defined $result->[0]->[1]) { #we got more than a single value, better warn
 					$self->q->errorHandler->dbReturnedMoreThanSingleValue;
@@ -703,7 +703,7 @@ sub update {
 
 		if ($additional) { #addional queries run on insert
 			foreach my $field (keys %$additional) {
-				my $result = $self->db->getarray(@{$additional->{$field}->{sql}});
+				my $result = $self->db->getarray($additional->{$field}->{sql});
 
 				if (defined $result->[1] || defined $result->[0]->[1]) { #we got more than a single value, better warn
 					$self->q->errorHandler->dbReturnedMoreThanSingleValue;
